@@ -25,12 +25,37 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <glib/gprintf.h>
+#include <glib-object.h>
 #include "glib-utils.h"
 
 
 #define MAX_PATTERNS 128
 
 
+/* gobject utils*/
+
+
+gpointer
+_g_object_ref (gpointer object)
+{
+	if (object != NULL)
+		return g_object_ref (object);
+	else
+		return NULL;
+}
+
+
+void
+_g_object_unref (gpointer object)
+{
+	if (object != NULL)
+		g_object_unref (object);
+}
+
+
+/* string utils */
+
+
 gboolean
 strchrs (const char *str,
 	 const char *chars)
@@ -159,32 +184,6 @@ escape_str (const char *str,
 }
 
 
-/* remove backslashes from a string. */
-char*
-unescape_str (const char  *str)
-{
-	char       *new_str;
-	const char *s;
-	char       *t;
-
-	if (str == NULL)
-		return NULL;
-
-	new_str = g_malloc (strlen (str) + 1);
-
-	s = str;
-	t = new_str;
-	while (*s) {
-		if (*s == '\\')
-			s++;
-		*t++ = *s++;
-	}
-	*t = 0;
-
-	return new_str;
-}
-
-
 /* escape with backslash the file name. */
 char*
 shell_escape (const char *filename)
@@ -609,6 +608,30 @@ g_ptr_array_reverse (GPtrArray *array)
 }
 
 
+int
+g_ptr_array_binary_search (GPtrArray    *array,
+			   gpointer      value,
+			   GCompareFunc  func)
+{
+	int l, r, p, cmp = -1;
+		
+	l = 0;
+	r = array->len;
+	while (l < r) {
+		p = l + ((r - l) / 2);
+		cmp = func(value, &g_ptr_array_index (array, p));
+		if (cmp == 0)
+			return p; 
+		else if (cmp < 0)
+			r = p;
+		else 
+			l = p + 1;
+	}
+	
+	return -1;
+}
+
+
 GHashTable *static_strings = NULL;
 
 
@@ -632,3 +655,59 @@ get_static_string (const char *s)
 
         return result;
 }
+
+
+char*
+g_uri_display_basename (const char  *uri)
+{
+	char *e_name, *name;
+	
+	e_name = g_filename_display_basename (uri);
+	name = g_uri_unescape_string (e_name, "");
+	g_free (e_name);
+	
+	return name;
+}
+
+
+char **
+_g_strv_prepend (char       **str_array,
+		 const char  *str)
+{
+	char **result;
+	int    i;
+	int    j;
+
+	result = g_new (char *, g_strv_length (str_array) + 1);
+	i = 0;
+	result[i++] = g_strdup (str);
+	for (j = 0; str_array[j] != NULL; j++)
+		result[i++] = g_strdup (str_array[j]);
+	result[i] = NULL;
+
+	return result;
+}
+
+
+gboolean
+_g_strv_remove (char       **str_array,
+		const char  *str)
+{
+	int i;
+	int j;
+
+	if (str == NULL)
+		return FALSE;
+
+	for (i = 0; str_array[i] != NULL; i++)
+		if (strcmp (str_array[i], str) == 0)
+			break;
+
+	if (str_array[i] == NULL)
+		return FALSE;
+
+	for (j = i; str_array[j] != NULL; j++)
+		str_array[j] = str_array[j + 1];
+
+	return TRUE;
+}
